@@ -2,6 +2,7 @@ package WWW::Webrobot::WebrobotLoad;
 use strict;
 use warnings;
 
+
 # Author: Stefan Trcek
 # Copyright(c) 2004 ABAS Software AG
 
@@ -14,16 +15,18 @@ use WWW::Webrobot::Histogram;
 use WWW::Webrobot::Print::ChildSend;
 
 
+my $USAGE = __PACKAGE__ . "->new(\$cfg, \$cmd_param)";
+
 =head1 NAME
 
 WWW::Webrobot::WebrobotLoad - Run testplans with multiple clients
 
 =head1 SYNOPSIS
 
-    my $cfg = WWW::Webrobot -> read_configuration($cfg_name, $cmd_param);
-    my $wrl = WWW::Webrobot::WebrobotLoad->new();
+    my $cmd_param = WWW::Webrobot::CGIHelper::param2list($cgi, [qw(cfg testplan)]);
+    my $wrl = WWW::Webrobot::WebrobotLoad->new($cfg_name, $cmd_param);
     my ($statistic, $histogram, $url_statistic, $http_errcode, $assert_ok) =
-        $wrl -> run($cfg, $testplan_name);
+         $wrl -> run($testplan_name);
 
 =head1 DESCRIPTION
 
@@ -36,21 +39,30 @@ Look into the sources L<webrobot-load>.
 
 =over
 
-=item $wr = WWW::Webrobot::WebrobotLoad -> new( );
+=item $wr = WWW::Webrobot::WebrobotLoad -> new( $cfg_name, $cmd_param );
 
 Construct an object.
 
+ $cfg_name
+     Name of the config file
+ $cmd_param
+     ??? to be documented
+
 =cut
 
 sub new {
     my $class = shift;
     my $self = bless({}, ref($class) || $class);
+    my ($cfg_name, $cmd_param) = @_;
+    $self->{cfg_name} = $cfg_name or die $USAGE;
+    $self->{cmd_param} = $cmd_param or die $USAGE;
+    $self->{cfg} = WWW::Webrobot -> read_configuration($self->{cfg_name}, $self->{cmd_param});
     WWW::Webrobot::Global->save_memory(1);
     return $self;
 }
 
 
-=item ($statistic, $histogram, $url_statistic, $http_errcode, $assert_ok) = run($cfg, $testplan_name);
+=item ($statistic, $histogram, $url_statistic, $http_errcode, $assert_ok) = run($testplan_name);
 
 Run a test.
 
@@ -58,10 +70,6 @@ B<INPUT VARIABLES:>
 
 =over
 
-=item $cfg
-
-Config, see L<WWW::Webrobot::pod::Config>
-
 =item $testplan_name
 
 Name of the testplan
@@ -91,22 +99,24 @@ see L<WWW::Webrobot::Histogram>
 =cut
 
 sub run {
-    my ($self, $cfg, $testplan_name) = @_;
+    my ($self, $testplan_name) = @_;
 
     my $statistic = WWW::Webrobot::Statistic -> new(extended => 1);
-    my $histogram = WWW::Webrobot::Histogram -> new(base => $cfg->{load}->{base} || 2);
+    #my $histogram = WWW::Webrobot::Histogram -> new(base => $cfg->{load}->{base} || 2);
+    my $histogram = WWW::Webrobot::Histogram -> new(base => $self->cfg->{load}->{base} || 2);
     my $url_statistic = {};
     my $http_errcode = {};
     my $assert_ok = [];
     my $forker = WWW::Webrobot::Forker -> new();
-    $forker -> fork_children($cfg->{load}->{number_of_clients}, child($cfg, $testplan_name));
+    #$forker -> fork_children($cfg->{load}->{number_of_clients}, $self->child($testplan_name));
+    $forker -> fork_children($self->cfg->{load}->{number_of_clients}, $self->child($testplan_name));
     $forker -> eventloop(parent($statistic, $histogram, $url_statistic, $http_errcode, $assert_ok));
     return ($statistic, $histogram, $url_statistic, $http_errcode, $assert_ok);
 }
 
 sub child {
-    my ($cfg, $testplan_name) = @_;
-    my $webrobot = WWW::Webrobot -> new($cfg);
+    my ($self, $testplan_name) = @_;
+    my $webrobot = WWW::Webrobot -> new($self->{cfg_name}, $self->{cmd_param});
     return sub {
         my ($child_id) = @_;
         my $exit = $webrobot -> run($testplan_name);
@@ -136,6 +146,10 @@ sub parent {
     }
 }
 
+sub cfg {
+    my ($self) = @_;
+    return $self->{cfg};
+}
 
 =back
 
